<?php

namespace Drupal\commerce_paybox_payment;

use Symfony\Component\HttpFoundation\Request;

/**
 * Class SignatureChecker.
 */
class SignatureChecker {

  /**
   * @return int
   */
  public static function checkSignature(Request $request) {
    $key = self::loadPublicKey();
    if (!$key) {
      return -1;
    }
    $data = self::getRequestData($request);
    $sig = $request->query->get('Signature');
    $sig = base64_decode($sig, TRUE);

    return openssl_verify($data, $sig, $key);
  }

  /**
   * @return string
   */
  private static function getRequestData(Request $request) {
    // Converts the array into a string of key=value.
    $args = [];
    foreach ($request->query->all() as $key => $value) {
      if ('Signature' === $key) {
        continue;
      }
      $args[] = $key . '=' . urlencode($value);
    }

    return implode('&', $args);
  }

  /**
   * @return false|resource
   */
  private static function loadPublicKey() {
    $keyFile = drupal_get_path('module', 'commerce_paybox_payment') . '/pubkey.pem';
    $fileSize = filesize($keyFile);

    if (!$fileSize) {
      return FALSE;
    }
    $fp = fopen($keyFile, 'r');
    $fileData = fread($fp, $fileSize);
    fclose($fp);

    if (!$fileData) {
      return FALSE;
    }

    return openssl_pkey_get_public($fileData);
  }

}
